@@ -4,7 +4,7 @@
 
     all possible exceptions
 
-    :copyright: (c) 2014-2020 by Onni Software Ltd.
+    :copyright: (c) 2014-2022 by Onni Software Ltd.
     :license: New BSD License, see LICENSE for more details
 """
 
@@ -21,12 +21,6 @@ class SupportingPluginAvailableButNotInstalled(Exception):
     pass
 
 
-class UpgradePlugin(Exception):
-    """raised when a known plugin is not compatible"""
-
-    pass
-
-
 class IntegerAccuracyLossError(Exception):
     """
     When an interger is greater than 999999999999999, ods loses its accuracy.
