@@ -1,8 +1,12 @@
+from pyexcel_io.book import (
+    BookReader,
+    BookWriter,
+    RWInterface,
+    _convert_content_to_stream,
+)
+from pyexcel_io._compact import BytesIO, StringIO
+
 from nose.tools import raises
-from pyexcel_io.book import RWInterface, BookReader, BookWriter
-from pyexcel_io.book import _convert_content_to_stream
-from pyexcel_io._compact import PY2, StringIO, BytesIO
-from nose import SkipTest
 
 
 @raises(NotImplementedError)
@@ -36,18 +40,12 @@ def test_book_writer():
 
 
 def test_convert_to_bytes_stream():
-    if PY2:
-        raise SkipTest('No need test in python 2')
-    else:
-        file_content = b'test'
-        stream = _convert_content_to_stream(file_content, 'csv')
-        assert isinstance(stream, StringIO)
+    file_content = b"test"
+    stream = _convert_content_to_stream(file_content, "csv")
+    assert isinstance(stream, StringIO)
 
 
 def test_convert_to_string_stream():
-    if PY2:
-        raise SkipTest('No need test in python 2')
-    else:
-        file_content = 'test'
-        stream = _convert_content_to_stream(file_content, 'csvz')
-        assert isinstance(stream, BytesIO)
+    file_content = "test"
+    stream = _convert_content_to_stream(file_content, "csvz")
+    assert isinstance(stream, BytesIO)
